<?php

namespace Blackwhite29\Fbuid\Providers;

use Illuminate\Support\ServiceProvider;

class FbuidServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'fbuid');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'fbuid');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('fbuid', function ($app) {
            return $this->app->make('Blackwhite29\Fbuid\Fbuid');
        });

// Bind Fbuids to repository
        $this->app->bind(
            \Blackwhite29\Fbuid\Interfaces\FbuidsRepositoryInterface::class,
            \Blackwhite29\Fbuid\Repositories\Eloquent\FbuidsRepository::class
        );        // Bind FbuidsCategories to repository
        $this->app->bind(
            \Blackwhite29\Fbuid\Interfaces\FbuidsCategoriesRepositoryInterface::class,
            \Blackwhite29\Fbuid\Repositories\Eloquent\FbuidsCategoriesRepository::class
        );

        $this->app->register(\Blackwhite29\Fbuid\Providers\AuthServiceProvider::class);
        $this->app->register(\Blackwhite29\Fbuid\Providers\EventServiceProvider::class);
        $this->app->register(\Blackwhite29\Fbuid\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['fbuid'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/fbuid.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/fbuid')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/fbuid')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
